@@ -9,7 +9,8 @@
 ; sub SH_index
    { my $s = shift
    ; $s->dfv_check( { required => 'email'
-                    , msgs     => { prefix => 'err_' }}
+                    , msgs     => { prefix => 'err_' }
+                    }
                   )
                   || $s->switch_to('myOtherPage')
    }
